@@ -2,7 +2,7 @@
 Revise.jl tracks source code changes and incorporates the changes to a running Julia session.
 
 Revise.jl works behind-the-scenes. To track a package, e.g. `Example`:
-```julia
+```julia-repl
 (@v1.6) pkg> dev Example        # make a development copy of the package
 [...pkg output omitted...]
 
@@ -34,12 +34,12 @@ module Revise
 # the VS Code extension integration.
 
 using OrderedCollections, CodeTracking, JuliaInterpreter, LoweredCodeUtils
+using Preferences: Preferences
 
-using CodeTracking: PkgFiles, basedir, srcfiles, basepath
+using CodeTracking: PkgFiles, basedir, srcfiles, basepath, MethodInfoKey
 using JuliaInterpreter: Compiled, Frame, Interpreter, LineTypes, RecursiveInterpreter
-using JuliaInterpreter: codelocs, finish_and_return!, get_return, is_doc_expr, isassign,
-                        isidentical, is_quotenode_egal, linetable, lookup, moduleof,
-                        pc_expr, scopeof, step_expr!
+using JuliaInterpreter: codelocs, get_return, is_doc_expr, isassign, is_quotenode_egal,
+                        linetable, lookup, moduleof, pc_expr, step_expr!
 using LoweredCodeUtils: next_or_nothing!, callee_matches
 
 include("packagedef.jl")
