@@ -1655,14 +1655,12 @@ function __init__()
 
     # Populate field types map cache (only on main process, not on workers)
     if __bpart__ && (isnothing(distributed_module) || distributed_module.myid() == 1)
-        Threads.@spawn :default @lock types_cache_lock for type in collect_all_subtypes(Any)
-            nflds = Base.Compiler.fieldcount_noerror(type)
-            if nflds !== nothing && nflds > 0
-                types = collect(Any, fieldtypes(type))
-            else
-                types = nothing
-            end
-            types_cache[type] = types
+        Threads.@spawn :default foreach_subtype(Any) do @nospecialize type
+            # Populating this cache can be time consuming (eg, 30s on an
+            # i7-7700HQ) so do this incrementally and yield() to the scheduler
+            # regularly so this thread gets a chance to exit if the user quits early
+            yield()
+            fieldtypes_cached(type)
         end
     end
     return nothing
