@@ -15,8 +15,7 @@ do_test("Backedges") && @testset "Backedges" begin
     # Find the inner struct def for the anonymous function
     idtype = findall(stmt->isexpr(stmt, :thunk) && isa(stmt.args[1], Core.CodeInfo), src.code)[end]
     src2 = src.code[idtype].args[1]
-    methodinfo = Revise.MethodInfo()
-    isrequired = Revise.minimal_evaluation!(methodinfo, frame, :sigs)[1]
+    isrequired = Revise.minimal_evaluation!(frame, :sigs)[1]
     laststmt = src.code[end]
     @assert isa(laststmt, Core.ReturnNode)
     to_skip = isa(laststmt.val, Revise.JuliaInterpreter.SSAValue) ? 2 : 1
@@ -41,7 +40,7 @@ do_test("Backedges") && @testset "Backedges" begin
         return planetdiameters[name]
     end
     """
-    mexs = Revise.parse_source!(Revise.ModuleExprsSigs(BackEdgesTest), src, "backedges_test.jl", BackEdgesTest)
+    mexs = Revise.parse_source!(Revise.ModuleExprsInfos(BackEdgesTest), src, "backedges_test.jl", BackEdgesTest)
     Revise.instantiate_sigs!(mexs)
     @test isempty(methods(BackEdgesTest.getdiameter))
     @test !isdefined(BackEdgesTest, :planetdiameters)
@@ -82,5 +81,4 @@ do_test("Backedges") && @testset "Backedges" begin
     """
     ex = Meta.parse(src)
     @test Revise.methods_by_execution(BackEdgesTest, ex) isa Tuple
-
 end
